# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetBackendIssuersResult',
    'AwaitableGetBackendIssuersResult',
    'get_backend_issuers',
    'get_backend_issuers_output',
]

@pulumi.output_type
class GetBackendIssuersResult:
    """
    A collection of values returned by getBackendIssuers.
    """
    def __init__(__self__, backend=None, id=None, key_info=None, key_info_json=None, keys=None, namespace=None):
        if backend and not isinstance(backend, str):
            raise TypeError("Expected argument 'backend' to be a str")
        pulumi.set(__self__, "backend", backend)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if key_info and not isinstance(key_info, dict):
            raise TypeError("Expected argument 'key_info' to be a dict")
        pulumi.set(__self__, "key_info", key_info)
        if key_info_json and not isinstance(key_info_json, str):
            raise TypeError("Expected argument 'key_info_json' to be a str")
        pulumi.set(__self__, "key_info_json", key_info_json)
        if keys and not isinstance(keys, list):
            raise TypeError("Expected argument 'keys' to be a list")
        pulumi.set(__self__, "keys", keys)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)

    @_builtins.property
    @pulumi.getter
    def backend(self) -> _builtins.str:
        return pulumi.get(self, "backend")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="keyInfo")
    def key_info(self) -> Mapping[str, _builtins.str]:
        """
        Map of issuer strings read from Vault.
        """
        return pulumi.get(self, "key_info")

    @_builtins.property
    @pulumi.getter(name="keyInfoJson")
    def key_info_json(self) -> _builtins.str:
        """
        JSON-encoded issuer data read from Vault.
        """
        return pulumi.get(self, "key_info_json")

    @_builtins.property
    @pulumi.getter
    def keys(self) -> Sequence[_builtins.str]:
        """
        Keys used by issuers under the backend path.
        """
        return pulumi.get(self, "keys")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "namespace")


class AwaitableGetBackendIssuersResult(GetBackendIssuersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBackendIssuersResult(
            backend=self.backend,
            id=self.id,
            key_info=self.key_info,
            key_info_json=self.key_info_json,
            keys=self.keys,
            namespace=self.namespace)


def get_backend_issuers(backend: Optional[_builtins.str] = None,
                        namespace: Optional[_builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBackendIssuersResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    pki = vault.Mount("pki",
        path="pki",
        type="pki",
        description="PKI secret engine mount")
    root = vault.pkisecret.SecretBackendRootCert("root",
        backend=pki.path,
        type="internal",
        common_name="example",
        ttl="86400",
        issuer_name="example")
    test = vault.pkiSecret.get_backend_issuers_output(backend=root.backend)
    ```


    :param _builtins.str backend: The path to the PKI secret backend to
           read the issuers from, with no leading or trailing `/`s.
    :param _builtins.str namespace: The namespace of the target resource.
           The value should not contain leading or trailing forward slashes.
           The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
           *Available only for Vault Enterprise*.
    """
    __args__ = dict()
    __args__['backend'] = backend
    __args__['namespace'] = namespace
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vault:pkiSecret/getBackendIssuers:getBackendIssuers', __args__, opts=opts, typ=GetBackendIssuersResult).value

    return AwaitableGetBackendIssuersResult(
        backend=pulumi.get(__ret__, 'backend'),
        id=pulumi.get(__ret__, 'id'),
        key_info=pulumi.get(__ret__, 'key_info'),
        key_info_json=pulumi.get(__ret__, 'key_info_json'),
        keys=pulumi.get(__ret__, 'keys'),
        namespace=pulumi.get(__ret__, 'namespace'))
def get_backend_issuers_output(backend: Optional[pulumi.Input[_builtins.str]] = None,
                               namespace: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBackendIssuersResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    pki = vault.Mount("pki",
        path="pki",
        type="pki",
        description="PKI secret engine mount")
    root = vault.pkisecret.SecretBackendRootCert("root",
        backend=pki.path,
        type="internal",
        common_name="example",
        ttl="86400",
        issuer_name="example")
    test = vault.pkiSecret.get_backend_issuers_output(backend=root.backend)
    ```


    :param _builtins.str backend: The path to the PKI secret backend to
           read the issuers from, with no leading or trailing `/`s.
    :param _builtins.str namespace: The namespace of the target resource.
           The value should not contain leading or trailing forward slashes.
           The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
           *Available only for Vault Enterprise*.
    """
    __args__ = dict()
    __args__['backend'] = backend
    __args__['namespace'] = namespace
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vault:pkiSecret/getBackendIssuers:getBackendIssuers', __args__, opts=opts, typ=GetBackendIssuersResult)
    return __ret__.apply(lambda __response__: GetBackendIssuersResult(
        backend=pulumi.get(__response__, 'backend'),
        id=pulumi.get(__response__, 'id'),
        key_info=pulumi.get(__response__, 'key_info'),
        key_info_json=pulumi.get(__response__, 'key_info_json'),
        keys=pulumi.get(__response__, 'keys'),
        namespace=pulumi.get(__response__, 'namespace')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetBackendCertMetadataResult',
    'AwaitableGetBackendCertMetadataResult',
    'get_backend_cert_metadata',
    'get_backend_cert_metadata_output',
]

@pulumi.output_type
class GetBackendCertMetadataResult:
    """
    A collection of values returned by getBackendCertMetadata.
    """
    def __init__(__self__, cert_metadata=None, expiration=None, id=None, issuer_id=None, namespace=None, path=None, role=None, serial=None, serial_number=None):
        if cert_metadata and not isinstance(cert_metadata, str):
            raise TypeError("Expected argument 'cert_metadata' to be a str")
        pulumi.set(__self__, "cert_metadata", cert_metadata)
        if expiration and not isinstance(expiration, str):
            raise TypeError("Expected argument 'expiration' to be a str")
        pulumi.set(__self__, "expiration", expiration)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if issuer_id and not isinstance(issuer_id, str):
            raise TypeError("Expected argument 'issuer_id' to be a str")
        pulumi.set(__self__, "issuer_id", issuer_id)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if path and not isinstance(path, str):
            raise TypeError("Expected argument 'path' to be a str")
        pulumi.set(__self__, "path", path)
        if role and not isinstance(role, str):
            raise TypeError("Expected argument 'role' to be a str")
        pulumi.set(__self__, "role", role)
        if serial and not isinstance(serial, str):
            raise TypeError("Expected argument 'serial' to be a str")
        pulumi.set(__self__, "serial", serial)
        if serial_number and not isinstance(serial_number, str):
            raise TypeError("Expected argument 'serial_number' to be a str")
        pulumi.set(__self__, "serial_number", serial_number)

    @_builtins.property
    @pulumi.getter(name="certMetadata")
    def cert_metadata(self) -> _builtins.str:
        """
        The metadata associated with the certificate
        """
        return pulumi.get(self, "cert_metadata")

    @_builtins.property
    @pulumi.getter
    def expiration(self) -> _builtins.str:
        """
        The expiration date of the certificate in unix epoch format
        """
        return pulumi.get(self, "expiration")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="issuerId")
    def issuer_id(self) -> _builtins.str:
        """
        ID of the issuer.
        """
        return pulumi.get(self, "issuer_id")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter
    def path(self) -> _builtins.str:
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter
    def role(self) -> _builtins.str:
        """
        The role used to create the certificate
        """
        return pulumi.get(self, "role")

    @_builtins.property
    @pulumi.getter
    def serial(self) -> _builtins.str:
        return pulumi.get(self, "serial")

    @_builtins.property
    @pulumi.getter(name="serialNumber")
    def serial_number(self) -> _builtins.str:
        """
        The serial number
        """
        return pulumi.get(self, "serial_number")


class AwaitableGetBackendCertMetadataResult(GetBackendCertMetadataResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBackendCertMetadataResult(
            cert_metadata=self.cert_metadata,
            expiration=self.expiration,
            id=self.id,
            issuer_id=self.issuer_id,
            namespace=self.namespace,
            path=self.path,
            role=self.role,
            serial=self.serial,
            serial_number=self.serial_number)


def get_backend_cert_metadata(namespace: Optional[_builtins.str] = None,
                              path: Optional[_builtins.str] = None,
                              serial: Optional[_builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBackendCertMetadataResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    pki = vault.Mount("pki",
        path="pki",
        type="pki",
        description="PKI secret engine mount")
    root = vault.pkisecret.SecretBackendRootCert("root",
        backend=pki.path,
        type="internal",
        common_name="example",
        ttl="86400",
        issuer_name="example")
    test_secret_backend_role = vault.pkisecret.SecretBackendRole("test",
        backend=test_vault_pki_secret_backend_root_cert["backend"],
        name="test",
        allowed_domains=["test.my.domain"],
        allow_subdomains=True,
        max_ttl="3600",
        key_usages=[
            "DigitalSignature",
            "KeyAgreement",
            "KeyEncipherment",
        ],
        no_store_metadata=False)
    test_secret_backend_cert = vault.pkisecret.SecretBackendCert("test",
        backend=test_secret_backend_role.backend,
        name=test_secret_backend_role.name,
        common_name="cert.test.my.domain",
        ttl="720h",
        min_seconds_remaining=60,
        cert_metadata="dGVzdCBtZXRhZGF0YQ==")
    test = test_secret_backend_cert.serial_number.apply(lambda serial_number: vault.pkiSecret.get_backend_cert_metadata_output(path=test_root["path"],
        serial=serial_number))
    ```


    :param _builtins.str namespace: The namespace of the target resource.
           The value should not contain leading or trailing forward slashes.
           The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
           *Available only for Vault Enterprise*.
    :param _builtins.str path: The path to the PKI secret backend to
           read the cert metadata from, with no leading or trailing `/`s.
    :param _builtins.str serial: Specifies the serial of the certificate whose metadata to read.
    """
    __args__ = dict()
    __args__['namespace'] = namespace
    __args__['path'] = path
    __args__['serial'] = serial
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vault:pkiSecret/getBackendCertMetadata:getBackendCertMetadata', __args__, opts=opts, typ=GetBackendCertMetadataResult).value

    return AwaitableGetBackendCertMetadataResult(
        cert_metadata=pulumi.get(__ret__, 'cert_metadata'),
        expiration=pulumi.get(__ret__, 'expiration'),
        id=pulumi.get(__ret__, 'id'),
        issuer_id=pulumi.get(__ret__, 'issuer_id'),
        namespace=pulumi.get(__ret__, 'namespace'),
        path=pulumi.get(__ret__, 'path'),
        role=pulumi.get(__ret__, 'role'),
        serial=pulumi.get(__ret__, 'serial'),
        serial_number=pulumi.get(__ret__, 'serial_number'))
def get_backend_cert_metadata_output(namespace: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                     path: Optional[pulumi.Input[_builtins.str]] = None,
                                     serial: Optional[pulumi.Input[_builtins.str]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBackendCertMetadataResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    pki = vault.Mount("pki",
        path="pki",
        type="pki",
        description="PKI secret engine mount")
    root = vault.pkisecret.SecretBackendRootCert("root",
        backend=pki.path,
        type="internal",
        common_name="example",
        ttl="86400",
        issuer_name="example")
    test_secret_backend_role = vault.pkisecret.SecretBackendRole("test",
        backend=test_vault_pki_secret_backend_root_cert["backend"],
        name="test",
        allowed_domains=["test.my.domain"],
        allow_subdomains=True,
        max_ttl="3600",
        key_usages=[
            "DigitalSignature",
            "KeyAgreement",
            "KeyEncipherment",
        ],
        no_store_metadata=False)
    test_secret_backend_cert = vault.pkisecret.SecretBackendCert("test",
        backend=test_secret_backend_role.backend,
        name=test_secret_backend_role.name,
        common_name="cert.test.my.domain",
        ttl="720h",
        min_seconds_remaining=60,
        cert_metadata="dGVzdCBtZXRhZGF0YQ==")
    test = test_secret_backend_cert.serial_number.apply(lambda serial_number: vault.pkiSecret.get_backend_cert_metadata_output(path=test_root["path"],
        serial=serial_number))
    ```


    :param _builtins.str namespace: The namespace of the target resource.
           The value should not contain leading or trailing forward slashes.
           The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
           *Available only for Vault Enterprise*.
    :param _builtins.str path: The path to the PKI secret backend to
           read the cert metadata from, with no leading or trailing `/`s.
    :param _builtins.str serial: Specifies the serial of the certificate whose metadata to read.
    """
    __args__ = dict()
    __args__['namespace'] = namespace
    __args__['path'] = path
    __args__['serial'] = serial
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vault:pkiSecret/getBackendCertMetadata:getBackendCertMetadata', __args__, opts=opts, typ=GetBackendCertMetadataResult)
    return __ret__.apply(lambda __response__: GetBackendCertMetadataResult(
        cert_metadata=pulumi.get(__response__, 'cert_metadata'),
        expiration=pulumi.get(__response__, 'expiration'),
        id=pulumi.get(__response__, 'id'),
        issuer_id=pulumi.get(__response__, 'issuer_id'),
        namespace=pulumi.get(__response__, 'namespace'),
        path=pulumi.get(__response__, 'path'),
        role=pulumi.get(__response__, 'role'),
        serial=pulumi.get(__response__, 'serial'),
        serial_number=pulumi.get(__response__, 'serial_number')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['CertAuthBackendRoleArgs', 'CertAuthBackendRole']

@pulumi.input_type
class CertAuthBackendRoleArgs:
    def __init__(__self__, *,
                 certificate: pulumi.Input[_builtins.str],
                 alias_metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 allowed_common_names: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_dns_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_email_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_names: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_organizational_units: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_uri_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 ocsp_ca_certificates: Optional[pulumi.Input[_builtins.str]] = None,
                 ocsp_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ocsp_fail_open: Optional[pulumi.Input[_builtins.bool]] = None,
                 ocsp_max_retries: Optional[pulumi.Input[_builtins.int]] = None,
                 ocsp_query_all_servers: Optional[pulumi.Input[_builtins.bool]] = None,
                 ocsp_servers_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ocsp_this_update_max_age: Optional[pulumi.Input[_builtins.int]] = None,
                 required_extensions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_bound_cidrs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_explicit_max_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 token_max_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 token_no_default_policy: Optional[pulumi.Input[_builtins.bool]] = None,
                 token_num_uses: Optional[pulumi.Input[_builtins.int]] = None,
                 token_period: Optional[pulumi.Input[_builtins.int]] = None,
                 token_policies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 token_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a CertAuthBackendRole resource.
        :param pulumi.Input[_builtins.str] certificate: CA certificate used to validate client certificates
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] alias_metadata: The metadata to be tied to generated entity alias.
                 This should be a list or map containing the metadata in key value pairs.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_common_names: Allowed the common names for authenticated client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_dns_sans: Allowed alternative dns names for authenticated client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_email_sans: Allowed emails for authenticated client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_names: DEPRECATED: Please use the individual `allowed_X_sans` parameters instead. Allowed subject names for authenticated client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_organizational_units: Allowed organization units for authenticated client certificates.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_uri_sans: Allowed URIs for authenticated client certificates
        :param pulumi.Input[_builtins.str] backend: Path to the mounted Cert auth backend
        :param pulumi.Input[_builtins.str] display_name: The name to display on tokens issued under this role.
        :param pulumi.Input[_builtins.str] name: Name of the role
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.str] ocsp_ca_certificates: Any additional CA certificates
               needed to verify OCSP responses. Provided as base64 encoded PEM data.
               Requires Vault version 1.13+.
        :param pulumi.Input[_builtins.bool] ocsp_enabled: If enabled, validate certificates'
               revocation status using OCSP. Requires Vault version 1.13+.
        :param pulumi.Input[_builtins.bool] ocsp_fail_open: If true and an OCSP response cannot
               be fetched or is of an unknown status, the login will proceed as if the
               certificate has not been revoked.
               Requires Vault version 1.13+.
        :param pulumi.Input[_builtins.int] ocsp_max_retries: The number of retries to attempt when
               connecting to an OCSP server. Defaults to 4 retries.
               Must be a non-negative value. Requires Vault version 1.16+.
        :param pulumi.Input[_builtins.bool] ocsp_query_all_servers: If set to true, rather than
               accepting the first successful OCSP response, query all servers and consider
               the certificate valid only if all servers agree.
               Requires Vault version 1.13+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ocsp_servers_overrides: : A comma-separated list of OCSP
               server addresses. If unset, the OCSP server is determined from the
               AuthorityInformationAccess extension on the certificate being inspected.
               Requires Vault version 1.13+.
        :param pulumi.Input[_builtins.int] ocsp_this_update_max_age: The maximum age in seconds of the
               'thisUpdate' field in an OCSP response before it is considered too old.
               Defaults to 0 (disabled). Must be a non-negative value.
               Requires Vault version 1.16+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] required_extensions: TLS extensions required on
               client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] token_bound_cidrs: Specifies the blocks of IP addresses which are allowed to use the generated token
        :param pulumi.Input[_builtins.int] token_explicit_max_ttl: Generated Token's Explicit Maximum TTL in seconds
        :param pulumi.Input[_builtins.int] token_max_ttl: The maximum lifetime of the generated token
        :param pulumi.Input[_builtins.bool] token_no_default_policy: If true, the 'default' policy will not automatically be added to generated tokens
        :param pulumi.Input[_builtins.int] token_num_uses: The maximum number of times a token may be used, a value of zero means unlimited
        :param pulumi.Input[_builtins.int] token_period: Generated Token's Period
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] token_policies: Generated Token's Policies
        :param pulumi.Input[_builtins.int] token_ttl: The initial ttl of the token to generate in seconds
        :param pulumi.Input[_builtins.str] token_type: The type of token to generate, service or batch
        """
        pulumi.set(__self__, "certificate", certificate)
        if alias_metadata is not None:
            pulumi.set(__self__, "alias_metadata", alias_metadata)
        if allowed_common_names is not None:
            pulumi.set(__self__, "allowed_common_names", allowed_common_names)
        if allowed_dns_sans is not None:
            pulumi.set(__self__, "allowed_dns_sans", allowed_dns_sans)
        if allowed_email_sans is not None:
            pulumi.set(__self__, "allowed_email_sans", allowed_email_sans)
        if allowed_names is not None:
            pulumi.set(__self__, "allowed_names", allowed_names)
        if allowed_organizational_units is not None:
            pulumi.set(__self__, "allowed_organizational_units", allowed_organizational_units)
        if allowed_uri_sans is not None:
            pulumi.set(__self__, "allowed_uri_sans", allowed_uri_sans)
        if backend is not None:
            pulumi.set(__self__, "backend", backend)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if ocsp_ca_certificates is not None:
            pulumi.set(__self__, "ocsp_ca_certificates", ocsp_ca_certificates)
        if ocsp_enabled is not None:
            pulumi.set(__self__, "ocsp_enabled", ocsp_enabled)
        if ocsp_fail_open is not None:
            pulumi.set(__self__, "ocsp_fail_open", ocsp_fail_open)
        if ocsp_max_retries is not None:
            pulumi.set(__self__, "ocsp_max_retries", ocsp_max_retries)
        if ocsp_query_all_servers is not None:
            pulumi.set(__self__, "ocsp_query_all_servers", ocsp_query_all_servers)
        if ocsp_servers_overrides is not None:
            pulumi.set(__self__, "ocsp_servers_overrides", ocsp_servers_overrides)
        if ocsp_this_update_max_age is not None:
            pulumi.set(__self__, "ocsp_this_update_max_age", ocsp_this_update_max_age)
        if required_extensions is not None:
            pulumi.set(__self__, "required_extensions", required_extensions)
        if token_bound_cidrs is not None:
            pulumi.set(__self__, "token_bound_cidrs", token_bound_cidrs)
        if token_explicit_max_ttl is not None:
            pulumi.set(__self__, "token_explicit_max_ttl", token_explicit_max_ttl)
        if token_max_ttl is not None:
            pulumi.set(__self__, "token_max_ttl", token_max_ttl)
        if token_no_default_policy is not None:
            pulumi.set(__self__, "token_no_default_policy", token_no_default_policy)
        if token_num_uses is not None:
            pulumi.set(__self__, "token_num_uses", token_num_uses)
        if token_period is not None:
            pulumi.set(__self__, "token_period", token_period)
        if token_policies is not None:
            pulumi.set(__self__, "token_policies", token_policies)
        if token_ttl is not None:
            pulumi.set(__self__, "token_ttl", token_ttl)
        if token_type is not None:
            pulumi.set(__self__, "token_type", token_type)

    @_builtins.property
    @pulumi.getter
    def certificate(self) -> pulumi.Input[_builtins.str]:
        """
        CA certificate used to validate client certificates
        """
        return pulumi.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "certificate", value)

    @_builtins.property
    @pulumi.getter(name="aliasMetadata")
    def alias_metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        The metadata to be tied to generated entity alias.
          This should be a list or map containing the metadata in key value pairs.
        """
        return pulumi.get(self, "alias_metadata")

    @alias_metadata.setter
    def alias_metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "alias_metadata", value)

    @_builtins.property
    @pulumi.getter(name="allowedCommonNames")
    def allowed_common_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Allowed the common names for authenticated client certificates
        """
        return pulumi.get(self, "allowed_common_names")

    @allowed_common_names.setter
    def allowed_common_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_common_names", value)

    @_builtins.property
    @pulumi.getter(name="allowedDnsSans")
    def allowed_dns_sans(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Allowed alternative dns names for authenticated client certificates
        """
        return pulumi.get(self, "allowed_dns_sans")

    @allowed_dns_sans.setter
    def allowed_dns_sans(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_dns_sans", value)

    @_builtins.property
    @pulumi.getter(name="allowedEmailSans")
    def allowed_email_sans(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Allowed emails for authenticated client certificates
        """
        return pulumi.get(self, "allowed_email_sans")

    @allowed_email_sans.setter
    def allowed_email_sans(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_email_sans", value)

    @_builtins.property
    @pulumi.getter(name="allowedNames")
    def allowed_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        DEPRECATED: Please use the individual `allowed_X_sans` parameters instead. Allowed subject names for authenticated client certificates
        """
        return pulumi.get(self, "allowed_names")

    @allowed_names.setter
    def allowed_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_names", value)

    @_builtins.property
    @pulumi.getter(name="allowedOrganizationalUnits")
    def allowed_organizational_units(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Allowed organization units for authenticated client certificates.
        """
        return pulumi.get(self, "allowed_organizational_units")

    @allowed_organizational_units.setter
    def allowed_organizational_units(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_organizational_units", value)

    @_builtins.property
    @pulumi.getter(name="allowedUriSans")
    def allowed_uri_sans(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Allowed URIs for authenticated client certificates
        """
        return pulumi.get(self, "allowed_uri_sans")

    @allowed_uri_sans.setter
    def allowed_uri_sans(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_uri_sans", value)

    @_builtins.property
    @pulumi.getter
    def backend(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path to the mounted Cert auth backend
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "backend", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name to display on tokens issued under this role.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the role
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)

    @_builtins.property
    @pulumi.getter(name="ocspCaCertificates")
    def ocsp_ca_certificates(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Any additional CA certificates
        needed to verify OCSP responses. Provided as base64 encoded PEM data.
        Requires Vault version 1.13+.
        """
        return pulumi.get(self, "ocsp_ca_certificates")

    @ocsp_ca_certificates.setter
    def ocsp_ca_certificates(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ocsp_ca_certificates", value)

    @_builtins.property
    @pulumi.getter(name="ocspEnabled")
    def ocsp_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If enabled, validate certificates'
        revocation status using OCSP. Requires Vault version 1.13+.
        """
        return pulumi.get(self, "ocsp_enabled")

    @ocsp_enabled.setter
    def ocsp_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "ocsp_enabled", value)

    @_builtins.property
    @pulumi.getter(name="ocspFailOpen")
    def ocsp_fail_open(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true and an OCSP response cannot
        be fetched or is of an unknown status, the login will proceed as if the
        certificate has not been revoked.
        Requires Vault version 1.13+.
        """
        return pulumi.get(self, "ocsp_fail_open")

    @ocsp_fail_open.setter
    def ocsp_fail_open(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "ocsp_fail_open", value)

    @_builtins.property
    @pulumi.getter(name="ocspMaxRetries")
    def ocsp_max_retries(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of retries to attempt when
        connecting to an OCSP server. Defaults to 4 retries.
        Must be a non-negative value. Requires Vault version 1.16+.
        """
        return pulumi.get(self, "ocsp_max_retries")

    @ocsp_max_retries.setter
    def ocsp_max_retries(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ocsp_max_retries", value)

    @_builtins.property
    @pulumi.getter(name="ocspQueryAllServers")
    def ocsp_query_all_servers(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If set to true, rather than
        accepting the first successful OCSP response, query all servers and consider
        the certificate valid only if all servers agree.
        Requires Vault version 1.13+.
        """
        return pulumi.get(self, "ocsp_query_all_servers")

    @ocsp_query_all_servers.setter
    def ocsp_query_all_servers(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "ocsp_query_all_servers", value)

    @_builtins.property
    @pulumi.getter(name="ocspServersOverrides")
    def ocsp_servers_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        : A comma-separated list of OCSP
        server addresses. If unset, the OCSP server is determined from the
        AuthorityInformationAccess extension on the certificate being inspected.
        Requires Vault version 1.13+.
        """
        return pulumi.get(self, "ocsp_servers_overrides")

    @ocsp_servers_overrides.setter
    def ocsp_servers_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ocsp_servers_overrides", value)

    @_builtins.property
    @pulumi.getter(name="ocspThisUpdateMaxAge")
    def ocsp_this_update_max_age(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum age in seconds of the
        'thisUpdate' field in an OCSP response before it is considered too old.
        Defaults to 0 (disabled). Must be a non-negative value.
        Requires Vault version 1.16+.
        """
        return pulumi.get(self, "ocsp_this_update_max_age")

    @ocsp_this_update_max_age.setter
    def ocsp_this_update_max_age(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ocsp_this_update_max_age", value)

    @_builtins.property
    @pulumi.getter(name="requiredExtensions")
    def required_extensions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        TLS extensions required on
        client certificates
        """
        return pulumi.get(self, "required_extensions")

    @required_extensions.setter
    def required_extensions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "required_extensions", value)

    @_builtins.property
    @pulumi.getter(name="tokenBoundCidrs")
    def token_bound_cidrs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Specifies the blocks of IP addresses which are allowed to use the generated token
        """
        return pulumi.get(self, "token_bound_cidrs")

    @token_bound_cidrs.setter
    def token_bound_cidrs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "token_bound_cidrs", value)

    @_builtins.property
    @pulumi.getter(name="tokenExplicitMaxTtl")
    def token_explicit_max_ttl(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Generated Token's Explicit Maximum TTL in seconds
        """
        return pulumi.get(self, "token_explicit_max_ttl")

    @token_explicit_max_ttl.setter
    def token_explicit_max_ttl(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "token_explicit_max_ttl", value)

    @_builtins.property
    @pulumi.getter(name="tokenMaxTtl")
    def token_max_ttl(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum lifetime of the generated token
        """
        return pulumi.get(self, "token_max_ttl")

    @token_max_ttl.setter
    def token_max_ttl(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "token_max_ttl", value)

    @_builtins.property
    @pulumi.getter(name="tokenNoDefaultPolicy")
    def token_no_default_policy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, the 'default' policy will not automatically be added to generated tokens
        """
        return pulumi.get(self, "token_no_default_policy")

    @token_no_default_policy.setter
    def token_no_default_policy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "token_no_default_policy", value)

    @_builtins.property
    @pulumi.getter(name="tokenNumUses")
    def token_num_uses(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum number of times a token may be used, a value of zero means unlimited
        """
        return pulumi.get(self, "token_num_uses")

    @token_num_uses.setter
    def token_num_uses(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "token_num_uses", value)

    @_builtins.property
    @pulumi.getter(name="tokenPeriod")
    def token_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Generated Token's Period
        """
        return pulumi.get(self, "token_period")

    @token_period.setter
    def token_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "token_period", value)

    @_builtins.property
    @pulumi.getter(name="tokenPolicies")
    def token_policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Generated Token's Policies
        """
        return pulumi.get(self, "token_policies")

    @token_policies.setter
    def token_policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "token_policies", value)

    @_builtins.property
    @pulumi.getter(name="tokenTtl")
    def token_ttl(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The initial ttl of the token to generate in seconds
        """
        return pulumi.get(self, "token_ttl")

    @token_ttl.setter
    def token_ttl(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "token_ttl", value)

    @_builtins.property
    @pulumi.getter(name="tokenType")
    def token_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of token to generate, service or batch
        """
        return pulumi.get(self, "token_type")

    @token_type.setter
    def token_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token_type", value)


@pulumi.input_type
class _CertAuthBackendRoleState:
    def __init__(__self__, *,
                 alias_metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 allowed_common_names: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_dns_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_email_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_names: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_organizational_units: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_uri_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 ocsp_ca_certificates: Optional[pulumi.Input[_builtins.str]] = None,
                 ocsp_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ocsp_fail_open: Optional[pulumi.Input[_builtins.bool]] = None,
                 ocsp_max_retries: Optional[pulumi.Input[_builtins.int]] = None,
                 ocsp_query_all_servers: Optional[pulumi.Input[_builtins.bool]] = None,
                 ocsp_servers_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ocsp_this_update_max_age: Optional[pulumi.Input[_builtins.int]] = None,
                 required_extensions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_bound_cidrs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_explicit_max_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 token_max_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 token_no_default_policy: Optional[pulumi.Input[_builtins.bool]] = None,
                 token_num_uses: Optional[pulumi.Input[_builtins.int]] = None,
                 token_period: Optional[pulumi.Input[_builtins.int]] = None,
                 token_policies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 token_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering CertAuthBackendRole resources.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] alias_metadata: The metadata to be tied to generated entity alias.
                 This should be a list or map containing the metadata in key value pairs.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_common_names: Allowed the common names for authenticated client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_dns_sans: Allowed alternative dns names for authenticated client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_email_sans: Allowed emails for authenticated client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_names: DEPRECATED: Please use the individual `allowed_X_sans` parameters instead. Allowed subject names for authenticated client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_organizational_units: Allowed organization units for authenticated client certificates.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_uri_sans: Allowed URIs for authenticated client certificates
        :param pulumi.Input[_builtins.str] backend: Path to the mounted Cert auth backend
        :param pulumi.Input[_builtins.str] certificate: CA certificate used to validate client certificates
        :param pulumi.Input[_builtins.str] display_name: The name to display on tokens issued under this role.
        :param pulumi.Input[_builtins.str] name: Name of the role
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.str] ocsp_ca_certificates: Any additional CA certificates
               needed to verify OCSP responses. Provided as base64 encoded PEM data.
               Requires Vault version 1.13+.
        :param pulumi.Input[_builtins.bool] ocsp_enabled: If enabled, validate certificates'
               revocation status using OCSP. Requires Vault version 1.13+.
        :param pulumi.Input[_builtins.bool] ocsp_fail_open: If true and an OCSP response cannot
               be fetched or is of an unknown status, the login will proceed as if the
               certificate has not been revoked.
               Requires Vault version 1.13+.
        :param pulumi.Input[_builtins.int] ocsp_max_retries: The number of retries to attempt when
               connecting to an OCSP server. Defaults to 4 retries.
               Must be a non-negative value. Requires Vault version 1.16+.
        :param pulumi.Input[_builtins.bool] ocsp_query_all_servers: If set to true, rather than
               accepting the first successful OCSP response, query all servers and consider
               the certificate valid only if all servers agree.
               Requires Vault version 1.13+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ocsp_servers_overrides: : A comma-separated list of OCSP
               server addresses. If unset, the OCSP server is determined from the
               AuthorityInformationAccess extension on the certificate being inspected.
               Requires Vault version 1.13+.
        :param pulumi.Input[_builtins.int] ocsp_this_update_max_age: The maximum age in seconds of the
               'thisUpdate' field in an OCSP response before it is considered too old.
               Defaults to 0 (disabled). Must be a non-negative value.
               Requires Vault version 1.16+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] required_extensions: TLS extensions required on
               client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] token_bound_cidrs: Specifies the blocks of IP addresses which are allowed to use the generated token
        :param pulumi.Input[_builtins.int] token_explicit_max_ttl: Generated Token's Explicit Maximum TTL in seconds
        :param pulumi.Input[_builtins.int] token_max_ttl: The maximum lifetime of the generated token
        :param pulumi.Input[_builtins.bool] token_no_default_policy: If true, the 'default' policy will not automatically be added to generated tokens
        :param pulumi.Input[_builtins.int] token_num_uses: The maximum number of times a token may be used, a value of zero means unlimited
        :param pulumi.Input[_builtins.int] token_period: Generated Token's Period
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] token_policies: Generated Token's Policies
        :param pulumi.Input[_builtins.int] token_ttl: The initial ttl of the token to generate in seconds
        :param pulumi.Input[_builtins.str] token_type: The type of token to generate, service or batch
        """
        if alias_metadata is not None:
            pulumi.set(__self__, "alias_metadata", alias_metadata)
        if allowed_common_names is not None:
            pulumi.set(__self__, "allowed_common_names", allowed_common_names)
        if allowed_dns_sans is not None:
            pulumi.set(__self__, "allowed_dns_sans", allowed_dns_sans)
        if allowed_email_sans is not None:
            pulumi.set(__self__, "allowed_email_sans", allowed_email_sans)
        if allowed_names is not None:
            pulumi.set(__self__, "allowed_names", allowed_names)
        if allowed_organizational_units is not None:
            pulumi.set(__self__, "allowed_organizational_units", allowed_organizational_units)
        if allowed_uri_sans is not None:
            pulumi.set(__self__, "allowed_uri_sans", allowed_uri_sans)
        if backend is not None:
            pulumi.set(__self__, "backend", backend)
        if certificate is not None:
            pulumi.set(__self__, "certificate", certificate)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if ocsp_ca_certificates is not None:
            pulumi.set(__self__, "ocsp_ca_certificates", ocsp_ca_certificates)
        if ocsp_enabled is not None:
            pulumi.set(__self__, "ocsp_enabled", ocsp_enabled)
        if ocsp_fail_open is not None:
            pulumi.set(__self__, "ocsp_fail_open", ocsp_fail_open)
        if ocsp_max_retries is not None:
            pulumi.set(__self__, "ocsp_max_retries", ocsp_max_retries)
        if ocsp_query_all_servers is not None:
            pulumi.set(__self__, "ocsp_query_all_servers", ocsp_query_all_servers)
        if ocsp_servers_overrides is not None:
            pulumi.set(__self__, "ocsp_servers_overrides", ocsp_servers_overrides)
        if ocsp_this_update_max_age is not None:
            pulumi.set(__self__, "ocsp_this_update_max_age", ocsp_this_update_max_age)
        if required_extensions is not None:
            pulumi.set(__self__, "required_extensions", required_extensions)
        if token_bound_cidrs is not None:
            pulumi.set(__self__, "token_bound_cidrs", token_bound_cidrs)
        if token_explicit_max_ttl is not None:
            pulumi.set(__self__, "token_explicit_max_ttl", token_explicit_max_ttl)
        if token_max_ttl is not None:
            pulumi.set(__self__, "token_max_ttl", token_max_ttl)
        if token_no_default_policy is not None:
            pulumi.set(__self__, "token_no_default_policy", token_no_default_policy)
        if token_num_uses is not None:
            pulumi.set(__self__, "token_num_uses", token_num_uses)
        if token_period is not None:
            pulumi.set(__self__, "token_period", token_period)
        if token_policies is not None:
            pulumi.set(__self__, "token_policies", token_policies)
        if token_ttl is not None:
            pulumi.set(__self__, "token_ttl", token_ttl)
        if token_type is not None:
            pulumi.set(__self__, "token_type", token_type)

    @_builtins.property
    @pulumi.getter(name="aliasMetadata")
    def alias_metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        The metadata to be tied to generated entity alias.
          This should be a list or map containing the metadata in key value pairs.
        """
        return pulumi.get(self, "alias_metadata")

    @alias_metadata.setter
    def alias_metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "alias_metadata", value)

    @_builtins.property
    @pulumi.getter(name="allowedCommonNames")
    def allowed_common_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Allowed the common names for authenticated client certificates
        """
        return pulumi.get(self, "allowed_common_names")

    @allowed_common_names.setter
    def allowed_common_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_common_names", value)

    @_builtins.property
    @pulumi.getter(name="allowedDnsSans")
    def allowed_dns_sans(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Allowed alternative dns names for authenticated client certificates
        """
        return pulumi.get(self, "allowed_dns_sans")

    @allowed_dns_sans.setter
    def allowed_dns_sans(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_dns_sans", value)

    @_builtins.property
    @pulumi.getter(name="allowedEmailSans")
    def allowed_email_sans(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Allowed emails for authenticated client certificates
        """
        return pulumi.get(self, "allowed_email_sans")

    @allowed_email_sans.setter
    def allowed_email_sans(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_email_sans", value)

    @_builtins.property
    @pulumi.getter(name="allowedNames")
    def allowed_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        DEPRECATED: Please use the individual `allowed_X_sans` parameters instead. Allowed subject names for authenticated client certificates
        """
        return pulumi.get(self, "allowed_names")

    @allowed_names.setter
    def allowed_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_names", value)

    @_builtins.property
    @pulumi.getter(name="allowedOrganizationalUnits")
    def allowed_organizational_units(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Allowed organization units for authenticated client certificates.
        """
        return pulumi.get(self, "allowed_organizational_units")

    @allowed_organizational_units.setter
    def allowed_organizational_units(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_organizational_units", value)

    @_builtins.property
    @pulumi.getter(name="allowedUriSans")
    def allowed_uri_sans(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Allowed URIs for authenticated client certificates
        """
        return pulumi.get(self, "allowed_uri_sans")

    @allowed_uri_sans.setter
    def allowed_uri_sans(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_uri_sans", value)

    @_builtins.property
    @pulumi.getter
    def backend(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path to the mounted Cert auth backend
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "backend", value)

    @_builtins.property
    @pulumi.getter
    def certificate(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        CA certificate used to validate client certificates
        """
        return pulumi.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "certificate", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name to display on tokens issued under this role.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the role
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)

    @_builtins.property
    @pulumi.getter(name="ocspCaCertificates")
    def ocsp_ca_certificates(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Any additional CA certificates
        needed to verify OCSP responses. Provided as base64 encoded PEM data.
        Requires Vault version 1.13+.
        """
        return pulumi.get(self, "ocsp_ca_certificates")

    @ocsp_ca_certificates.setter
    def ocsp_ca_certificates(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ocsp_ca_certificates", value)

    @_builtins.property
    @pulumi.getter(name="ocspEnabled")
    def ocsp_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If enabled, validate certificates'
        revocation status using OCSP. Requires Vault version 1.13+.
        """
        return pulumi.get(self, "ocsp_enabled")

    @ocsp_enabled.setter
    def ocsp_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "ocsp_enabled", value)

    @_builtins.property
    @pulumi.getter(name="ocspFailOpen")
    def ocsp_fail_open(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true and an OCSP response cannot
        be fetched or is of an unknown status, the login will proceed as if the
        certificate has not been revoked.
        Requires Vault version 1.13+.
        """
        return pulumi.get(self, "ocsp_fail_open")

    @ocsp_fail_open.setter
    def ocsp_fail_open(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "ocsp_fail_open", value)

    @_builtins.property
    @pulumi.getter(name="ocspMaxRetries")
    def ocsp_max_retries(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of retries to attempt when
        connecting to an OCSP server. Defaults to 4 retries.
        Must be a non-negative value. Requires Vault version 1.16+.
        """
        return pulumi.get(self, "ocsp_max_retries")

    @ocsp_max_retries.setter
    def ocsp_max_retries(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ocsp_max_retries", value)

    @_builtins.property
    @pulumi.getter(name="ocspQueryAllServers")
    def ocsp_query_all_servers(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If set to true, rather than
        accepting the first successful OCSP response, query all servers and consider
        the certificate valid only if all servers agree.
        Requires Vault version 1.13+.
        """
        return pulumi.get(self, "ocsp_query_all_servers")

    @ocsp_query_all_servers.setter
    def ocsp_query_all_servers(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "ocsp_query_all_servers", value)

    @_builtins.property
    @pulumi.getter(name="ocspServersOverrides")
    def ocsp_servers_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        : A comma-separated list of OCSP
        server addresses. If unset, the OCSP server is determined from the
        AuthorityInformationAccess extension on the certificate being inspected.
        Requires Vault version 1.13+.
        """
        return pulumi.get(self, "ocsp_servers_overrides")

    @ocsp_servers_overrides.setter
    def ocsp_servers_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ocsp_servers_overrides", value)

    @_builtins.property
    @pulumi.getter(name="ocspThisUpdateMaxAge")
    def ocsp_this_update_max_age(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum age in seconds of the
        'thisUpdate' field in an OCSP response before it is considered too old.
        Defaults to 0 (disabled). Must be a non-negative value.
        Requires Vault version 1.16+.
        """
        return pulumi.get(self, "ocsp_this_update_max_age")

    @ocsp_this_update_max_age.setter
    def ocsp_this_update_max_age(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ocsp_this_update_max_age", value)

    @_builtins.property
    @pulumi.getter(name="requiredExtensions")
    def required_extensions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        TLS extensions required on
        client certificates
        """
        return pulumi.get(self, "required_extensions")

    @required_extensions.setter
    def required_extensions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "required_extensions", value)

    @_builtins.property
    @pulumi.getter(name="tokenBoundCidrs")
    def token_bound_cidrs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Specifies the blocks of IP addresses which are allowed to use the generated token
        """
        return pulumi.get(self, "token_bound_cidrs")

    @token_bound_cidrs.setter
    def token_bound_cidrs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "token_bound_cidrs", value)

    @_builtins.property
    @pulumi.getter(name="tokenExplicitMaxTtl")
    def token_explicit_max_ttl(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Generated Token's Explicit Maximum TTL in seconds
        """
        return pulumi.get(self, "token_explicit_max_ttl")

    @token_explicit_max_ttl.setter
    def token_explicit_max_ttl(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "token_explicit_max_ttl", value)

    @_builtins.property
    @pulumi.getter(name="tokenMaxTtl")
    def token_max_ttl(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum lifetime of the generated token
        """
        return pulumi.get(self, "token_max_ttl")

    @token_max_ttl.setter
    def token_max_ttl(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "token_max_ttl", value)

    @_builtins.property
    @pulumi.getter(name="tokenNoDefaultPolicy")
    def token_no_default_policy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, the 'default' policy will not automatically be added to generated tokens
        """
        return pulumi.get(self, "token_no_default_policy")

    @token_no_default_policy.setter
    def token_no_default_policy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "token_no_default_policy", value)

    @_builtins.property
    @pulumi.getter(name="tokenNumUses")
    def token_num_uses(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum number of times a token may be used, a value of zero means unlimited
        """
        return pulumi.get(self, "token_num_uses")

    @token_num_uses.setter
    def token_num_uses(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "token_num_uses", value)

    @_builtins.property
    @pulumi.getter(name="tokenPeriod")
    def token_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Generated Token's Period
        """
        return pulumi.get(self, "token_period")

    @token_period.setter
    def token_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "token_period", value)

    @_builtins.property
    @pulumi.getter(name="tokenPolicies")
    def token_policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Generated Token's Policies
        """
        return pulumi.get(self, "token_policies")

    @token_policies.setter
    def token_policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "token_policies", value)

    @_builtins.property
    @pulumi.getter(name="tokenTtl")
    def token_ttl(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The initial ttl of the token to generate in seconds
        """
        return pulumi.get(self, "token_ttl")

    @token_ttl.setter
    def token_ttl(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "token_ttl", value)

    @_builtins.property
    @pulumi.getter(name="tokenType")
    def token_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of token to generate, service or batch
        """
        return pulumi.get(self, "token_type")

    @token_type.setter
    def token_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token_type", value)


@pulumi.type_token("vault:index/certAuthBackendRole:CertAuthBackendRole")
class CertAuthBackendRole(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alias_metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 allowed_common_names: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_dns_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_email_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_names: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_organizational_units: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_uri_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 ocsp_ca_certificates: Optional[pulumi.Input[_builtins.str]] = None,
                 ocsp_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ocsp_fail_open: Optional[pulumi.Input[_builtins.bool]] = None,
                 ocsp_max_retries: Optional[pulumi.Input[_builtins.int]] = None,
                 ocsp_query_all_servers: Optional[pulumi.Input[_builtins.bool]] = None,
                 ocsp_servers_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ocsp_this_update_max_age: Optional[pulumi.Input[_builtins.int]] = None,
                 required_extensions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_bound_cidrs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_explicit_max_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 token_max_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 token_no_default_policy: Optional[pulumi.Input[_builtins.bool]] = None,
                 token_num_uses: Optional[pulumi.Input[_builtins.int]] = None,
                 token_period: Optional[pulumi.Input[_builtins.int]] = None,
                 token_policies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 token_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Provides a resource to create a role in an [Cert auth backend within Vault](https://www.vaultproject.io/docs/auth/cert.html).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_std as std
        import pulumi_vault as vault

        cert = vault.AuthBackend("cert",
            path="cert",
            type="cert")
        cert_cert_auth_backend_role = vault.CertAuthBackendRole("cert",
            name="foo",
            certificate=std.file(input="/path/to/certs/ca-cert.pem").result,
            backend=cert.path,
            allowed_names=[
                "foo.example.org",
                "baz.example.org",
            ],
            token_ttl=300,
            token_max_ttl=600,
            token_policies=["foo"])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] alias_metadata: The metadata to be tied to generated entity alias.
                 This should be a list or map containing the metadata in key value pairs.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_common_names: Allowed the common names for authenticated client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_dns_sans: Allowed alternative dns names for authenticated client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_email_sans: Allowed emails for authenticated client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_names: DEPRECATED: Please use the individual `allowed_X_sans` parameters instead. Allowed subject names for authenticated client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_organizational_units: Allowed organization units for authenticated client certificates.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_uri_sans: Allowed URIs for authenticated client certificates
        :param pulumi.Input[_builtins.str] backend: Path to the mounted Cert auth backend
        :param pulumi.Input[_builtins.str] certificate: CA certificate used to validate client certificates
        :param pulumi.Input[_builtins.str] display_name: The name to display on tokens issued under this role.
        :param pulumi.Input[_builtins.str] name: Name of the role
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.str] ocsp_ca_certificates: Any additional CA certificates
               needed to verify OCSP responses. Provided as base64 encoded PEM data.
               Requires Vault version 1.13+.
        :param pulumi.Input[_builtins.bool] ocsp_enabled: If enabled, validate certificates'
               revocation status using OCSP. Requires Vault version 1.13+.
        :param pulumi.Input[_builtins.bool] ocsp_fail_open: If true and an OCSP response cannot
               be fetched or is of an unknown status, the login will proceed as if the
               certificate has not been revoked.
               Requires Vault version 1.13+.
        :param pulumi.Input[_builtins.int] ocsp_max_retries: The number of retries to attempt when
               connecting to an OCSP server. Defaults to 4 retries.
               Must be a non-negative value. Requires Vault version 1.16+.
        :param pulumi.Input[_builtins.bool] ocsp_query_all_servers: If set to true, rather than
               accepting the first successful OCSP response, query all servers and consider
               the certificate valid only if all servers agree.
               Requires Vault version 1.13+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ocsp_servers_overrides: : A comma-separated list of OCSP
               server addresses. If unset, the OCSP server is determined from the
               AuthorityInformationAccess extension on the certificate being inspected.
               Requires Vault version 1.13+.
        :param pulumi.Input[_builtins.int] ocsp_this_update_max_age: The maximum age in seconds of the
               'thisUpdate' field in an OCSP response before it is considered too old.
               Defaults to 0 (disabled). Must be a non-negative value.
               Requires Vault version 1.16+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] required_extensions: TLS extensions required on
               client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] token_bound_cidrs: Specifies the blocks of IP addresses which are allowed to use the generated token
        :param pulumi.Input[_builtins.int] token_explicit_max_ttl: Generated Token's Explicit Maximum TTL in seconds
        :param pulumi.Input[_builtins.int] token_max_ttl: The maximum lifetime of the generated token
        :param pulumi.Input[_builtins.bool] token_no_default_policy: If true, the 'default' policy will not automatically be added to generated tokens
        :param pulumi.Input[_builtins.int] token_num_uses: The maximum number of times a token may be used, a value of zero means unlimited
        :param pulumi.Input[_builtins.int] token_period: Generated Token's Period
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] token_policies: Generated Token's Policies
        :param pulumi.Input[_builtins.int] token_ttl: The initial ttl of the token to generate in seconds
        :param pulumi.Input[_builtins.str] token_type: The type of token to generate, service or batch
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CertAuthBackendRoleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a resource to create a role in an [Cert auth backend within Vault](https://www.vaultproject.io/docs/auth/cert.html).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_std as std
        import pulumi_vault as vault

        cert = vault.AuthBackend("cert",
            path="cert",
            type="cert")
        cert_cert_auth_backend_role = vault.CertAuthBackendRole("cert",
            name="foo",
            certificate=std.file(input="/path/to/certs/ca-cert.pem").result,
            backend=cert.path,
            allowed_names=[
                "foo.example.org",
                "baz.example.org",
            ],
            token_ttl=300,
            token_max_ttl=600,
            token_policies=["foo"])
        ```

        :param str resource_name: The name of the resource.
        :param CertAuthBackendRoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CertAuthBackendRoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alias_metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 allowed_common_names: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_dns_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_email_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_names: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_organizational_units: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_uri_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 ocsp_ca_certificates: Optional[pulumi.Input[_builtins.str]] = None,
                 ocsp_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ocsp_fail_open: Optional[pulumi.Input[_builtins.bool]] = None,
                 ocsp_max_retries: Optional[pulumi.Input[_builtins.int]] = None,
                 ocsp_query_all_servers: Optional[pulumi.Input[_builtins.bool]] = None,
                 ocsp_servers_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ocsp_this_update_max_age: Optional[pulumi.Input[_builtins.int]] = None,
                 required_extensions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_bound_cidrs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_explicit_max_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 token_max_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 token_no_default_policy: Optional[pulumi.Input[_builtins.bool]] = None,
                 token_num_uses: Optional[pulumi.Input[_builtins.int]] = None,
                 token_period: Optional[pulumi.Input[_builtins.int]] = None,
                 token_policies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 token_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CertAuthBackendRoleArgs.__new__(CertAuthBackendRoleArgs)

            __props__.__dict__["alias_metadata"] = alias_metadata
            __props__.__dict__["allowed_common_names"] = allowed_common_names
            __props__.__dict__["allowed_dns_sans"] = allowed_dns_sans
            __props__.__dict__["allowed_email_sans"] = allowed_email_sans
            __props__.__dict__["allowed_names"] = allowed_names
            __props__.__dict__["allowed_organizational_units"] = allowed_organizational_units
            __props__.__dict__["allowed_uri_sans"] = allowed_uri_sans
            __props__.__dict__["backend"] = backend
            if certificate is None and not opts.urn:
                raise TypeError("Missing required property 'certificate'")
            __props__.__dict__["certificate"] = certificate
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["name"] = name
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["ocsp_ca_certificates"] = ocsp_ca_certificates
            __props__.__dict__["ocsp_enabled"] = ocsp_enabled
            __props__.__dict__["ocsp_fail_open"] = ocsp_fail_open
            __props__.__dict__["ocsp_max_retries"] = ocsp_max_retries
            __props__.__dict__["ocsp_query_all_servers"] = ocsp_query_all_servers
            __props__.__dict__["ocsp_servers_overrides"] = ocsp_servers_overrides
            __props__.__dict__["ocsp_this_update_max_age"] = ocsp_this_update_max_age
            __props__.__dict__["required_extensions"] = required_extensions
            __props__.__dict__["token_bound_cidrs"] = token_bound_cidrs
            __props__.__dict__["token_explicit_max_ttl"] = token_explicit_max_ttl
            __props__.__dict__["token_max_ttl"] = token_max_ttl
            __props__.__dict__["token_no_default_policy"] = token_no_default_policy
            __props__.__dict__["token_num_uses"] = token_num_uses
            __props__.__dict__["token_period"] = token_period
            __props__.__dict__["token_policies"] = token_policies
            __props__.__dict__["token_ttl"] = token_ttl
            __props__.__dict__["token_type"] = token_type
        super(CertAuthBackendRole, __self__).__init__(
            'vault:index/certAuthBackendRole:CertAuthBackendRole',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alias_metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            allowed_common_names: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            allowed_dns_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            allowed_email_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            allowed_names: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            allowed_organizational_units: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            allowed_uri_sans: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            backend: Optional[pulumi.Input[_builtins.str]] = None,
            certificate: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            namespace: Optional[pulumi.Input[_builtins.str]] = None,
            ocsp_ca_certificates: Optional[pulumi.Input[_builtins.str]] = None,
            ocsp_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            ocsp_fail_open: Optional[pulumi.Input[_builtins.bool]] = None,
            ocsp_max_retries: Optional[pulumi.Input[_builtins.int]] = None,
            ocsp_query_all_servers: Optional[pulumi.Input[_builtins.bool]] = None,
            ocsp_servers_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            ocsp_this_update_max_age: Optional[pulumi.Input[_builtins.int]] = None,
            required_extensions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            token_bound_cidrs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            token_explicit_max_ttl: Optional[pulumi.Input[_builtins.int]] = None,
            token_max_ttl: Optional[pulumi.Input[_builtins.int]] = None,
            token_no_default_policy: Optional[pulumi.Input[_builtins.bool]] = None,
            token_num_uses: Optional[pulumi.Input[_builtins.int]] = None,
            token_period: Optional[pulumi.Input[_builtins.int]] = None,
            token_policies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            token_ttl: Optional[pulumi.Input[_builtins.int]] = None,
            token_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'CertAuthBackendRole':
        """
        Get an existing CertAuthBackendRole resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] alias_metadata: The metadata to be tied to generated entity alias.
                 This should be a list or map containing the metadata in key value pairs.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_common_names: Allowed the common names for authenticated client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_dns_sans: Allowed alternative dns names for authenticated client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_email_sans: Allowed emails for authenticated client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_names: DEPRECATED: Please use the individual `allowed_X_sans` parameters instead. Allowed subject names for authenticated client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_organizational_units: Allowed organization units for authenticated client certificates.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_uri_sans: Allowed URIs for authenticated client certificates
        :param pulumi.Input[_builtins.str] backend: Path to the mounted Cert auth backend
        :param pulumi.Input[_builtins.str] certificate: CA certificate used to validate client certificates
        :param pulumi.Input[_builtins.str] display_name: The name to display on tokens issued under this role.
        :param pulumi.Input[_builtins.str] name: Name of the role
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.str] ocsp_ca_certificates: Any additional CA certificates
               needed to verify OCSP responses. Provided as base64 encoded PEM data.
               Requires Vault version 1.13+.
        :param pulumi.Input[_builtins.bool] ocsp_enabled: If enabled, validate certificates'
               revocation status using OCSP. Requires Vault version 1.13+.
        :param pulumi.Input[_builtins.bool] ocsp_fail_open: If true and an OCSP response cannot
               be fetched or is of an unknown status, the login will proceed as if the
               certificate has not been revoked.
               Requires Vault version 1.13+.
        :param pulumi.Input[_builtins.int] ocsp_max_retries: The number of retries to attempt when
               connecting to an OCSP server. Defaults to 4 retries.
               Must be a non-negative value. Requires Vault version 1.16+.
        :param pulumi.Input[_builtins.bool] ocsp_query_all_servers: If set to true, rather than
               accepting the first successful OCSP response, query all servers and consider
               the certificate valid only if all servers agree.
               Requires Vault version 1.13+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ocsp_servers_overrides: : A comma-separated list of OCSP
               server addresses. If unset, the OCSP server is determined from the
               AuthorityInformationAccess extension on the certificate being inspected.
               Requires Vault version 1.13+.
        :param pulumi.Input[_builtins.int] ocsp_this_update_max_age: The maximum age in seconds of the
               'thisUpdate' field in an OCSP response before it is considered too old.
               Defaults to 0 (disabled). Must be a non-negative value.
               Requires Vault version 1.16+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] required_extensions: TLS extensions required on
               client certificates
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] token_bound_cidrs: Specifies the blocks of IP addresses which are allowed to use the generated token
        :param pulumi.Input[_builtins.int] token_explicit_max_ttl: Generated Token's Explicit Maximum TTL in seconds
        :param pulumi.Input[_builtins.int] token_max_ttl: The maximum lifetime of the generated token
        :param pulumi.Input[_builtins.bool] token_no_default_policy: If true, the 'default' policy will not automatically be added to generated tokens
        :param pulumi.Input[_builtins.int] token_num_uses: The maximum number of times a token may be used, a value of zero means unlimited
        :param pulumi.Input[_builtins.int] token_period: Generated Token's Period
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] token_policies: Generated Token's Policies
        :param pulumi.Input[_builtins.int] token_ttl: The initial ttl of the token to generate in seconds
        :param pulumi.Input[_builtins.str] token_type: The type of token to generate, service or batch
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CertAuthBackendRoleState.__new__(_CertAuthBackendRoleState)

        __props__.__dict__["alias_metadata"] = alias_metadata
        __props__.__dict__["allowed_common_names"] = allowed_common_names
        __props__.__dict__["allowed_dns_sans"] = allowed_dns_sans
        __props__.__dict__["allowed_email_sans"] = allowed_email_sans
        __props__.__dict__["allowed_names"] = allowed_names
        __props__.__dict__["allowed_organizational_units"] = allowed_organizational_units
        __props__.__dict__["allowed_uri_sans"] = allowed_uri_sans
        __props__.__dict__["backend"] = backend
        __props__.__dict__["certificate"] = certificate
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["name"] = name
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["ocsp_ca_certificates"] = ocsp_ca_certificates
        __props__.__dict__["ocsp_enabled"] = ocsp_enabled
        __props__.__dict__["ocsp_fail_open"] = ocsp_fail_open
        __props__.__dict__["ocsp_max_retries"] = ocsp_max_retries
        __props__.__dict__["ocsp_query_all_servers"] = ocsp_query_all_servers
        __props__.__dict__["ocsp_servers_overrides"] = ocsp_servers_overrides
        __props__.__dict__["ocsp_this_update_max_age"] = ocsp_this_update_max_age
        __props__.__dict__["required_extensions"] = required_extensions
        __props__.__dict__["token_bound_cidrs"] = token_bound_cidrs
        __props__.__dict__["token_explicit_max_ttl"] = token_explicit_max_ttl
        __props__.__dict__["token_max_ttl"] = token_max_ttl
        __props__.__dict__["token_no_default_policy"] = token_no_default_policy
        __props__.__dict__["token_num_uses"] = token_num_uses
        __props__.__dict__["token_period"] = token_period
        __props__.__dict__["token_policies"] = token_policies
        __props__.__dict__["token_ttl"] = token_ttl
        __props__.__dict__["token_type"] = token_type
        return CertAuthBackendRole(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="aliasMetadata")
    def alias_metadata(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        The metadata to be tied to generated entity alias.
          This should be a list or map containing the metadata in key value pairs.
        """
        return pulumi.get(self, "alias_metadata")

    @_builtins.property
    @pulumi.getter(name="allowedCommonNames")
    def allowed_common_names(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Allowed the common names for authenticated client certificates
        """
        return pulumi.get(self, "allowed_common_names")

    @_builtins.property
    @pulumi.getter(name="allowedDnsSans")
    def allowed_dns_sans(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Allowed alternative dns names for authenticated client certificates
        """
        return pulumi.get(self, "allowed_dns_sans")

    @_builtins.property
    @pulumi.getter(name="allowedEmailSans")
    def allowed_email_sans(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Allowed emails for authenticated client certificates
        """
        return pulumi.get(self, "allowed_email_sans")

    @_builtins.property
    @pulumi.getter(name="allowedNames")
    def allowed_names(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        DEPRECATED: Please use the individual `allowed_X_sans` parameters instead. Allowed subject names for authenticated client certificates
        """
        return pulumi.get(self, "allowed_names")

    @_builtins.property
    @pulumi.getter(name="allowedOrganizationalUnits")
    def allowed_organizational_units(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Allowed organization units for authenticated client certificates.
        """
        return pulumi.get(self, "allowed_organizational_units")

    @_builtins.property
    @pulumi.getter(name="allowedUriSans")
    def allowed_uri_sans(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Allowed URIs for authenticated client certificates
        """
        return pulumi.get(self, "allowed_uri_sans")

    @_builtins.property
    @pulumi.getter
    def backend(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Path to the mounted Cert auth backend
        """
        return pulumi.get(self, "backend")

    @_builtins.property
    @pulumi.getter
    def certificate(self) -> pulumi.Output[_builtins.str]:
        """
        CA certificate used to validate client certificates
        """
        return pulumi.get(self, "certificate")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name to display on tokens issued under this role.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the role
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter(name="ocspCaCertificates")
    def ocsp_ca_certificates(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Any additional CA certificates
        needed to verify OCSP responses. Provided as base64 encoded PEM data.
        Requires Vault version 1.13+.
        """
        return pulumi.get(self, "ocsp_ca_certificates")

    @_builtins.property
    @pulumi.getter(name="ocspEnabled")
    def ocsp_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        If enabled, validate certificates'
        revocation status using OCSP. Requires Vault version 1.13+.
        """
        return pulumi.get(self, "ocsp_enabled")

    @_builtins.property
    @pulumi.getter(name="ocspFailOpen")
    def ocsp_fail_open(self) -> pulumi.Output[_builtins.bool]:
        """
        If true and an OCSP response cannot
        be fetched or is of an unknown status, the login will proceed as if the
        certificate has not been revoked.
        Requires Vault version 1.13+.
        """
        return pulumi.get(self, "ocsp_fail_open")

    @_builtins.property
    @pulumi.getter(name="ocspMaxRetries")
    def ocsp_max_retries(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The number of retries to attempt when
        connecting to an OCSP server. Defaults to 4 retries.
        Must be a non-negative value. Requires Vault version 1.16+.
        """
        return pulumi.get(self, "ocsp_max_retries")

    @_builtins.property
    @pulumi.getter(name="ocspQueryAllServers")
    def ocsp_query_all_servers(self) -> pulumi.Output[_builtins.bool]:
        """
        If set to true, rather than
        accepting the first successful OCSP response, query all servers and consider
        the certificate valid only if all servers agree.
        Requires Vault version 1.13+.
        """
        return pulumi.get(self, "ocsp_query_all_servers")

    @_builtins.property
    @pulumi.getter(name="ocspServersOverrides")
    def ocsp_servers_overrides(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        : A comma-separated list of OCSP
        server addresses. If unset, the OCSP server is determined from the
        AuthorityInformationAccess extension on the certificate being inspected.
        Requires Vault version 1.13+.
        """
        return pulumi.get(self, "ocsp_servers_overrides")

    @_builtins.property
    @pulumi.getter(name="ocspThisUpdateMaxAge")
    def ocsp_this_update_max_age(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The maximum age in seconds of the
        'thisUpdate' field in an OCSP response before it is considered too old.
        Defaults to 0 (disabled). Must be a non-negative value.
        Requires Vault version 1.16+.
        """
        return pulumi.get(self, "ocsp_this_update_max_age")

    @_builtins.property
    @pulumi.getter(name="requiredExtensions")
    def required_extensions(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        TLS extensions required on
        client certificates
        """
        return pulumi.get(self, "required_extensions")

    @_builtins.property
    @pulumi.getter(name="tokenBoundCidrs")
    def token_bound_cidrs(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Specifies the blocks of IP addresses which are allowed to use the generated token
        """
        return pulumi.get(self, "token_bound_cidrs")

    @_builtins.property
    @pulumi.getter(name="tokenExplicitMaxTtl")
    def token_explicit_max_ttl(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Generated Token's Explicit Maximum TTL in seconds
        """
        return pulumi.get(self, "token_explicit_max_ttl")

    @_builtins.property
    @pulumi.getter(name="tokenMaxTtl")
    def token_max_ttl(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The maximum lifetime of the generated token
        """
        return pulumi.get(self, "token_max_ttl")

    @_builtins.property
    @pulumi.getter(name="tokenNoDefaultPolicy")
    def token_no_default_policy(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        If true, the 'default' policy will not automatically be added to generated tokens
        """
        return pulumi.get(self, "token_no_default_policy")

    @_builtins.property
    @pulumi.getter(name="tokenNumUses")
    def token_num_uses(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The maximum number of times a token may be used, a value of zero means unlimited
        """
        return pulumi.get(self, "token_num_uses")

    @_builtins.property
    @pulumi.getter(name="tokenPeriod")
    def token_period(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Generated Token's Period
        """
        return pulumi.get(self, "token_period")

    @_builtins.property
    @pulumi.getter(name="tokenPolicies")
    def token_policies(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Generated Token's Policies
        """
        return pulumi.get(self, "token_policies")

    @_builtins.property
    @pulumi.getter(name="tokenTtl")
    def token_ttl(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The initial ttl of the token to generate in seconds
        """
        return pulumi.get(self, "token_ttl")

    @_builtins.property
    @pulumi.getter(name="tokenType")
    def token_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The type of token to generate, service or batch
        """
        return pulumi.get(self, "token_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'SecretV2CustomMetadata',
]

@pulumi.output_type
class SecretV2CustomMetadata(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "casRequired":
            suggest = "cas_required"
        elif key == "deleteVersionAfter":
            suggest = "delete_version_after"
        elif key == "maxVersions":
            suggest = "max_versions"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SecretV2CustomMetadata. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SecretV2CustomMetadata.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SecretV2CustomMetadata.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cas_required: Optional[_builtins.bool] = None,
                 data: Optional[Mapping[str, _builtins.str]] = None,
                 delete_version_after: Optional[_builtins.int] = None,
                 max_versions: Optional[_builtins.int] = None):
        """
        :param _builtins.bool cas_required: If true, all keys will require the cas parameter to be set on all write requests.
        :param Mapping[str, _builtins.str] data: **Deprecated. Please use new ephemeral resource `kv.SecretV2` to read back
               secret data from Vault**. A mapping whose keys are the top-level data keys returned from
               Vault and whose values are the corresponding values. This map can only represent string data,
               so any non-string values returned from Vault are serialized as JSON.
        :param _builtins.int delete_version_after: If set, specifies the length of time before a version is deleted.
        :param _builtins.int max_versions: The number of versions to keep per key.
        """
        if cas_required is not None:
            pulumi.set(__self__, "cas_required", cas_required)
        if data is not None:
            pulumi.set(__self__, "data", data)
        if delete_version_after is not None:
            pulumi.set(__self__, "delete_version_after", delete_version_after)
        if max_versions is not None:
            pulumi.set(__self__, "max_versions", max_versions)

    @_builtins.property
    @pulumi.getter(name="casRequired")
    def cas_required(self) -> Optional[_builtins.bool]:
        """
        If true, all keys will require the cas parameter to be set on all write requests.
        """
        return pulumi.get(self, "cas_required")

    @_builtins.property
    @pulumi.getter
    def data(self) -> Optional[Mapping[str, _builtins.str]]:
        """
        **Deprecated. Please use new ephemeral resource `kv.SecretV2` to read back
        secret data from Vault**. A mapping whose keys are the top-level data keys returned from
        Vault and whose values are the corresponding values. This map can only represent string data,
        so any non-string values returned from Vault are serialized as JSON.
        """
        return pulumi.get(self, "data")

    @_builtins.property
    @pulumi.getter(name="deleteVersionAfter")
    def delete_version_after(self) -> Optional[_builtins.int]:
        """
        If set, specifies the length of time before a version is deleted.
        """
        return pulumi.get(self, "delete_version_after")

    @_builtins.property
    @pulumi.getter(name="maxVersions")
    def max_versions(self) -> Optional[_builtins.int]:
        """
        The number of versions to keep per key.
        """
        return pulumi.get(self, "max_versions")


